#
# spec file for package perl-Parallel-ForkManager
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Parallel-ForkManager
Name:           perl-Parallel-ForkManager
Version:        2.30.0
Release:        bp160.1.8
# 2.03 -> normalize -> 2.30.0
%define cpan_version 2.03
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Simple parallel processing fork manager
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/Y/YA/YANICK/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Moo) >= 1.001000
BuildRequires:  perl(Moo::Role)
BuildRequires:  perl(Test::More) >= 0.94
BuildRequires:  perl(Test::Warn)
Requires:       perl(Moo) >= 1.001000
Requires:       perl(Moo::Role)
Provides:       perl(Parallel::ForkManager) = %{version}
Provides:       perl(Parallel::ForkManager::Child) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This module is intended for use in operations that can be done in parallel
where the number of processes to be forked off should be limited. Typical
use is a downloader which will be retrieving hundreds/thousands of files.

The code for a downloader would look something like this:

  use LWP::Simple;
  use Parallel::ForkManager;

  ...

  my @links=(
    ["http://www.foo.bar/rulez.data","rulez_data.txt"],
    ["http://new.host/more_data.doc","more_data.doc"],
    ...
  );

  ...

  # Max 30 processes for parallel download
  my $pm = Parallel::ForkManager->new(30);

  LINKS:
  foreach my $linkarray (@links) {
    $pm->start and next LINKS; # do the fork

    my ($link, $fn) = @$linkarray;
    warn "Cannot get $fn from $link"
      if getstore($link, $fn) != RC_OK;

    $pm->finish; # do the exit in the child process
  }
  $pm->wait_all_children;

First you need to instantiate the ForkManager with the "new" constructor.
You must specify the maximum number of processes to be created. If you
specify 0, then NO fork will be done; this is good for debugging purposes.

Next, use $pm->start to do the fork. $pm returns 0 for the child process,
and child pid for the parent process (see also perlfunc/fork). The "and
next" skips the internal loop in the parent process. NOTE: $pm->start dies
if the fork fails.

$pm->finish terminates the child process (assuming a fork was done in the
"start").

NOTE: You cannot use $pm->start if you are already in the child process. If
you want to manage another set of subprocesses in the child process, you
must instantiate another Parallel::ForkManager object!

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CODE_OF_CONDUCT.md CONTRIBUTORS doap.xml examples README.mkdn

%changelog
* Sun Sep  1 2024 Tina Müller <timueller+perl@suse.de>
- updated to 2.30.0 (2.03)
  see /usr/share/doc/packages/perl-Parallel-ForkManager/Changes
  2.03 2024-08-24
  [BUG FIXES]
  - Fix invalid default error when using old Moo (GH#41)
  [DOCUMENTATION]
  - Standardize the link to `fork`. (GH#32)
  - Fix typo in code example. (GH#31, dimir)
  - Fix typo for 'max_proc' argument in `new`.
  [STATISTICS]
  - code churn: 6 files changed, 186 insertions(+), 48 deletions(-)
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 2.02
  see /usr/share/doc/packages/perl-Parallel-ForkManager/Changes
  2.02 2018-10-08
  - Promote to stable release.
  2.01 2018-08-23
    [ ENHANCEMENTS ]
  - add 'child_role' attribute for customization.
  2.00 2018-08-22 (TRIAL)
    [ API CHANGES ]
  - Change the guts to be Moo-based. (GH#24)
* Thu Jul 19 2018 coolo@suse.com
- updated to 1.20
  see /usr/share/doc/packages/perl-Parallel-ForkManager/Changes
  1.20 2018-07-18
    [ DOCUMENTATION ]
  - Add section about rand() and forked processes. (GH#22)
    [ ENHANCEMENTS ]
  - Expand abbreviations in error messages. (GH#14, Ricardo Signes)
  - Rename variables and simplify `_waitpid` signature. (GH#14, Ricardo
    Signes)
    [ STATISTICS ]
  - code churn: 6 files changed, 80 insertions(+), 33 deletions(-)
* Mon Jul  4 2016 coolo@suse.com
- updated to 1.19
  see /usr/share/doc/packages/perl-Parallel-ForkManager/Changes
  1.19 2016-06-28
    [ DOCUMENTATION ]
  - Typo fixes. (GH#10)
  - Add short discussion on security about the information passing via
    files between master/children processes.
  - Document the problem between PerlIO::fzip and fork(). (GH#11)
    [ ENHANCEMENTS ]
  - New way to spawn workers via 'start_child'.
    [ STATISTICS ]
  - code churn: 4 files changed, 114 insertions(+), 5 deletions(-)
* Mon Apr  4 2016 coolo@suse.com
- updated to 1.18
  see /usr/share/doc/packages/perl-Parallel-ForkManager/Changes
  1.18 2016-03-29
    [ BUG FIXES ]
  - Storage file between child and parent could have the wrong name,
    because $$ was used instead of parent_pid. (GH#9, reported by Lucien
    Coffe)
    [ STATISTICS ]
  - code churn: 4 files changed, 37 insertions(+), 4 deletions(-)
* Sun Nov 29 2015 coolo@suse.com
- updated to 1.17
  see /usr/share/doc/packages/perl-Parallel-ForkManager/Changes
  1.17 2015-11-28
  - Up Test::More's dependency version to v0.94 (because of 'subtest').
    (GH#8, mauke)
    [ STATISTICS ]
  - code churn: 3 files changed, 88 insertions(+), 70 deletions(-)
* Sat Oct 10 2015 coolo@suse.com
- updated to 1.16
  see /usr/share/doc/packages/perl-Parallel-ForkManager/Changes
* Sun Jul 12 2015 coolo@suse.com
- updated to 1.15
  see /usr/share/doc/packages/perl-Parallel-ForkManager/Changes
  1.15 2015.07.08
  - test's watchdog actually exit if it's being hit. (RT#105747, Zefram)
  - condition to catch children reaped by external forces
    improved. (RT#105748, Zefram + Yanick)
* Mon May 18 2015 coolo@suse.com
- updated to 1.14
  see /usr/share/doc/packages/perl-Parallel-ForkManager/Changes
  1.14 2015.05.17
  - Add 'reap_finished_children', 'is_child' and 'is_parent'. (GH#6, Nine bit)
* Wed May 13 2015 coolo@suse.com
- updated to 1.13
  see /usr/share/doc/packages/perl-Parallel-ForkManager/Changes
  1.13 2015.05.11
  - Use 'select' instead of sleep in _waitpid_blocking. (GH#5)
* Mon Mar 23 2015 mpluskal@suse.com
- Update to 1.12
  * for full list of changes see attaced Changes
* Fri Apr 22 2011 coolo@opensuse.org
- initial package 0.7.9
  * created by cpanspec 1.78.04
